===========
Input grids
===========

SWAN input grids commands

 
.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.inpgrid.REGULAR
   rompy_swan.components.inpgrid.CURVILINEAR
   rompy_swan.components.inpgrid.UNSTRUCTURED
   rompy_swan.components.inpgrid.WIND
   rompy_swan.components.inpgrid.ICE